/* 
 * <START_COPYRIGHT>
 * Copyright (c) 2005 University of Southampton
 * See CPL.txt for license information.
 * http://www.opensource.org/license/cpl1.0.txt
 * <END_COPYRIGHT>
 */

package org.gridprovenance.client.impl;

import java.security.Principal;
import java.util.Map;

import org.apache.axis.message.addressing.EndpointReference;
import org.gridprovenance.client.ProvenanceService;
import org.gridprovenance.client.XQuery;
import org.gridprovenance.client.PQuery;
import org.gridprovenance.client.InteractionRecord;
import org.gridprovenance.client.ViewKind;
import org.gridprovenance.client.InteractionKey;
import org.gridprovenance.client.RecordPort;
import org.gridprovenance.client.XQueryPort;
import org.gridprovenance.client.PQueryPort;

import org.gridprovenance.client.utilities.InteractionIdFactory;

import org.gridprovenance.client.exception.CSLException;

/**
 * An implement of ProvenanceStore interface<p>
 * CSL of EU Provenance 
 *
 * @author Sheng Jiang
 */

public class ProvenanceServiceImpl implements ProvenanceService {
	private EndpointReference recordPortAddress;
	private EndpointReference xQueryPortAddress;
	private EndpointReference pQueryPortAddress;

	public ProvenanceServiceImpl ()
	throws CSLException {
	}

	public ProvenanceServiceImpl (RecordPort recordPort, XQueryPort xQueryPort, PQueryPort pQueryPort)
	throws CSLException {
		this.recordPortAddress = recordPort.getRecordPort();
		this.xQueryPortAddress = xQueryPort.getXQueryPort();
		this.pQueryPortAddress = pQueryPort.getPQueryPort();
	}
	
	public EndpointReference getRecordPortAddress ()
	throws CSLException {
		return(this.recordPortAddress);
	}

	public EndpointReference getXQueryPortAddress ()
	throws CSLException {
		return(this.xQueryPortAddress);
	}

	public EndpointReference getPQueryPortAddress ()
	throws CSLException {
		return(this.pQueryPortAddress);
	}

	public InteractionRecord newInteractionRecord (EndpointReference msgSink, EndpointReference msgSource, Principal asserter, ViewKind vk)
	throws Exception, CSLException {
		InteractionKey ik = new InteractionKeyImpl (InteractionIdFactory.newInstance(), msgSink, msgSource);
		InteractionRecord newInteractionRecord  = new InteractionRecordImpl (vk, ik, asserter, this.recordPortAddress);
		return newInteractionRecord;
	}

	public XQuery newXQuery (String optionString)
	throws CSLException{
		XQuery xQuery = new XQueryImpl(optionString, this.xQueryPortAddress);
		return xQuery;
	}
	
	public PQuery newPQuery (String xPath1, String xPath2, Map namespace)
	throws CSLException{
		PQuery pQuery = new PQueryImpl(xPath1, xPath2, namespace, this.pQueryPortAddress);
		return pQuery;
	}

	public PQuery newPQuery (String xPath1, Map namespace1, String xPath2, Map namespace2)
	throws CSLException{
		PQuery pQuery = new PQueryImpl(xPath1, namespace1, xPath2, namespace2, this.pQueryPortAddress);
		return pQuery;
	}

}
