/* 
 * <START_COPYRIGHT>
 * Copyright (c) 2005 University of Southampton
 * See CPL.txt for license information.
 * http://www.opensource.org/license/cpl1.0.txt
 * <END_COPYRIGHT>
 */

package org.gridprovenance.client.utilities;

import java.security.Principal;
import javax.security.auth.x500.X500Principal;
import org.apache.axis.message.MessageElement;
import org.w3c.dom.Element;
import org.gridprovenance.client.generated.pstruct.Asserter;
import org.gridprovenance.client.utilities.ElementUtil;
import org.gridprovenance.client.exception.CSLException;

/**
 * A factory class for making a new instance of<p>
 * org.gridprovenance.client.generated.pstruct.Asserter from String<p>
 * CSL of EU Provenance
 *
 * @author Sheng Jiang
 */

public class AsserterUtil {
	
    /**
     * Create a new Asserter from given String
     * 
     * @return Asserter
     */
    public static Asserter newAsserter(String asString)
    throws Exception, CSLException  {

        Element asElement = ElementUtil.newElement(asString);

        MessageElement[] asArray = new MessageElement[1];
        asArray[0] = new MessageElement(asElement);

	Asserter as = new Asserter(asArray);
	return as;
    }

    /**
     * Create a new Asserter from given Principal
     * 
     * @return Asserter
     */
    public static Asserter newAsserter(Principal asPrincipal)
    throws Exception, CSLException  {
    	String asString = "<Principal>" + asPrincipal + "</Principal>";
        Element asElement = ElementUtil.newElement(asString);

        MessageElement[] asArray = new MessageElement[1];
        asArray[0] = new MessageElement(asElement);

	Asserter as = new Asserter(asArray);
	return as;
    }

    /**
     * Convert an Asserter into String
     * 
     * @return String
     */
    public static String toString(Asserter inputAsserter)
    throws CSLException {
    	String asserterString = "";
    	return (asserterString);
    }

    /**
     * Convert an Asserter into Principal
     * 
     * @return Principal
     */
    public static Principal toPrincipal(Asserter inputAsserter)
    throws CSLException {
    	Principal asPrincipal = new X500Principal("");
    	return (asPrincipal);
    }
}
