/*
 * <START_COPYRIGHT>
 * Copyright (c) 2005 University of Southampton
 * See CPL.txt for license information.
 * http://www.opensource.org/license/cpl1.0.txt
 * <END_COPYRIGHT>
 */

package org.gridprovenance.client.utilities;

import java.io.StringReader;
import java.io.File;

import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.DocumentBuilder;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.InputSource;

import org.gridprovenance.client.exception.CSLException;

/**
 * A factory class for making a new instance of <p>
 * Element from String<p>
 * CSL of EU Provenance
 *
 * @author Sheng Jiang
 */

public class ElementUtil {

    /**
     * Convert a String into Element
     *
     * @return Element
     */
    public static Element newElement (String inputString)
    throws Exception, CSLException {
        DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
        dbf.setNamespaceAware(true);
        DocumentBuilder db = dbf.newDocumentBuilder();
        Document msgDoc = db.parse(new InputSource(new StringReader(inputString)));
        Element outputElement = msgDoc.getDocumentElement();
    return outputElement;
    }

    /**
     * Parse an XML file and return the root Element
     *
     * @return Element
     */

    public static Element newElement (File fs)
    throws Exception, CSLException {
        DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
        dbf.setNamespaceAware(true);
        DocumentBuilder db = dbf.newDocumentBuilder();
        Document msgDoc = db.parse(fs);
        Element outputElement = msgDoc.getDocumentElement();
    return outputElement;
    }




    /**
     * Convert an Element into String
     *
     * @return String
     */
    public static String toString(Element inputElement)
    throws CSLException {
        String elementString = inputElement.toString();
        return elementString;
    }
}
